from __future__ import unicode_literals
import time
import pyfiglet
from youtubesearchpython import VideosSearch
from youtubesearchpython import *
import json
import __future__
import youtube_dl

def pymymusic():
    result = pyfiglet.figlet_format("PYMYMUSIC")
    print(result)
    song = input("Enter the song name:")
    videosSearch = VideosSearch(song, limit = 1)
    data = json.dumps(videosSearch.result())
    data = json.loads(data)

    print(type(data['result']))
    for result in data['result']:
        link = (result['link'])

    url = link
    print(url)
    filename = f"{song}.mp3"
    ydl_opts = {
            'format':'bestaudio/best',
            'keepvideo':False,
            'outtmpl':filename,
    }
    with youtube_dl.YoutubeDL(ydl_opts) as ydl:
        ydl.download([url])

    print("Thankyou for Downloading the Video {}".format(filename))
    print('your file is saved in admin folder')

pymymusic()


from setuptools import setup, find_packages


VERSION = '0.0.1'
DESCRIPTION = 'Download youtube music fast'
LONG_DESCRIPTION = 'pymymusic is a cli based youtube music downloader just type name of song hit enter and see the magic.'

#setup
setup(name='pymymusic',
version=VERSION,
description=DESCRIPTION,
long_description=LONG_DESCRIPTION,
url='https://github.com/unlikelycreator/pymynote',
author='iamhritikpawar',
author_email='hritikpawar.personal@gmail.com',
license='MIT',
packages=find_packages(),
install_requires=['youtube-search-python', 'youtube_dl', 'future', 'pyfiglet', 'jsons'],
zip_safe=False)